==> guile-2.0.9-x86_64-1.txz: usr/lib64/guile/2.0/ccache/language/elisp/runtime.go <==
GOOF----LE-8-2.0      ]  4      h`      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
g  filenameS	f  language/elisp/runtime.scm	g  exportsS	
g  	nil-value	g  t-value	g  value-slot-module	g  function-slot-module	g  
elisp-bool	g  
ensure-fluid!	g  reference-variable	g  
set-variable!	g  
runtime-error	g  macro-error	g  
built-in-func	g  built-in-macro	g  
defspecial	g  prim	
 	g  set-current-module	 	 	g  
value-slot	  	!g  
function-slot	"! 	#g  error	$g  resolve-interface	%g  resolve-module	&g  module-defined?	'g  make-unbound-fluid	(g  module-define!	)g  module-export!	*g  
module-ref	+g  module-set!	,g  make-syntax-transformer	-, 	., 	/g  macro	0g  $sc-dispatch	10 	20 	3g  any	4333 	5g  
syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  m-qfuOq@jzODoMRmvfm6NU6e-258	?>7 	@?88 	Af  l-qfuOq@jzODoMRmvfm6NU6e-263	Bf  l-qfuOq@jzODoMRmvfm6NU6e-264	Cf  l-qfuOq@jzODoMRmvfm6NU6e-265	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  l-qfuOq@jzODoMRmvfm6NU6e-260	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
define-public	R5QMO 	Sg  syntax-violation	TS 	US 	Vf  -source expression failed to match any pattern	Wg  
datum->syntax	Xg  map	Yg  identifier?	Zg  
syntax->datum	[g  identity	\g  string->symbol	]g  
string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  l-qfuOq@jzODoMRmvfm6NU6e-289	gf 	h9deg 	i;< 	j88 	kf  l-qfuOq@jzODoMRmvfm6NU6e-283	lf  l-qfuOq@jzODoMRmvfm6NU6e-284	mkl 	n9ijm 	of  l-qfuOq@jzODoMRmvfm6NU6e-280	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  l-qfuOq@jzODoMRmvfm6NU6e-303   9de  g  args g  body ;  888  f  l-qfuOq@jzODoMRmvfm6NU6e-295 f  l-qfuOq@jzODoMRmvfm6NU6e-296 f  l-qfuOq@jzODoMRmvfm6NU6e-297   9  f  l-qfuOq@jzODoMRmvfm6NU6e-292   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  m-qfuOq@jzODoMRmvfm6NU6e-306 7  88  f  l-qfuOq@jzODoMRmvfm6NU6e-311 f  l-qfuOq@jzODoMRmvfm6NU6e-312 f  l-qfuOq@jzODoMRmvfm6NU6e-313   9    f  l-qfuOq@jzODoMRmvfm6NU6e-308   9H  8F  5O  5O   C 5   h     ]4	
5 4 >  "  G   
RR R"R#        h      - 1 3  @              g  msg
			 g  args			  g  filenamef  language/elisp/runtime.scm
	5
		6	 			
  g  nameg  macro-error CRiR
     h   {   ] $  CC  s       g  b
		  g  filenamef  language/elisp/runtime.scm
	<
		=	 		  g  nameg  
elisp-bool CR$%&'()  hP     ]4 54 545$  C45 4>  "  G   6           g  module
		K g  sym		K g  intf			K g  resolved			K g  fluid		(	K  g  filenamef  language/elisp/runtime.scm
	G
		H		
	I			H			J	
	!	J		$	K		(	K		+	L	
	I	M	#	K	M	
 		K	  g  nameg  
ensure-fluid! CR%*  h@      ]
4 5 $  64 >  "  G  45[C            g  module
		; g  sym		; g  resolved				;  g  filenamef  language/elisp/runtime.scm
	O
		P				P			R			Q			S			U		1	V	 			;	  g  nameg  reference-variable CR$%&+()* 
       h   >  ]4 54 5 $  X45$  4>  "  G  "  -4>  "  G  4 >  "  G  "   4 >  "  G  4	5\C  6      g  module
	  g  sym	  g  value		  g  intf		  g  resolved		   g  filenamef  language/elisp/runtime.scm
	X
		Y		
	Z			Y			\			[			^		*	]		+	_		E	a		[	b		d	b	 	i	b		v	d	 	e	 	 	  g  nameg  
set-variable! CR4./24PR   h   R   ]  C       J       g  dummy
		 g  name		 g  value			  			   CUV       h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
	l	 		"  g  
macro-typeg  syntax-rulesg  patternsg  nameg  value   C5RWXYZ[     h    y   ]4 5$  "   6       q       g  datum
		  g  filenamef  language/elisp/runtime.scm
	x			y	 	
	y			y	 		   C\]^      h0      - 1 3  454445?56       g  template-id
			0 g  data			0 g  symbols			.  g  filenamef  language/elisp/runtime.scm
	q
		x			w			t			u			u	!	)	u		+	t		0	v	 
			0
  g  nameg  make-id C_R4./2a_bstvx|     h0      ]
4  5    C             g  name
		* g  value		* g  tmp		
	*  g  filenamef  language/elisp/runtime.scm	 	"		 	2	
 	"	
 	 		*	   CUV        h(   n   ]	4 5$  @ 6      f       g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"   C5R4./2_ 	    h0      ]4  5    C       g  name
		0 g  args		0 g  body			0 g  tmp		
	0  g  filenamef  language/elisp/runtime.scm	 	"		 	2	
 	"	
 	 		0	   CUV       h(   n   ]	4 5$  @ 6      f       g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"   C5R4./2 h   P   ] C H       g  dummy
		 g  sym		 g  args			  			   CUV h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"  g  
macro-typeg  syntax-rulesg  patternsg  symg  argsg  ...   C5RC           g  m
		(  g  filenamef  language/elisp/runtime.scm		
	,	%
	0	'
	2	-		5	-
	7	/		:	/
 	5
	8
	<
*	G
b	O
i	X
		q
 	
   C6 

==> guile-2.0.11-x86_64-1.txz: usr/lib64/guile/2.0/ccache/language/elisp/runtime.go <==
GOOF----LE-8-2.0      ]  4      h`      ] g  guile	 	g  define-module*	 	 	g  language	g  elisp	g  runtime		 	
g  filenameS	f  language/elisp/runtime.scm	g  exportsS	
g  	nil-value	g  t-value	g  value-slot-module	g  function-slot-module	g  
elisp-bool	g  
ensure-fluid!	g  reference-variable	g  
set-variable!	g  
runtime-error	g  macro-error	g  
built-in-func	g  built-in-macro	g  
defspecial	g  prim	
 	g  set-current-module	 	 	g  
value-slot	  	!g  
function-slot	"! 	#g  error	$g  resolve-interface	%g  resolve-module	&g  module-defined?	'g  make-unbound-fluid	(g  module-define!	)g  module-export!	*g  
module-ref	+g  module-set!	,g  make-syntax-transformer	-, 	., 	/g  macro	0g  $sc-dispatch	10 	20 	3g  any	4333 	5g  
syntax-object	6g  begin	7g  top	87 	9g  ribcage	:g  dummy	;g  name	<g  value	=:;< 	>g  m-vFAKOcByQc3koUD$JPeSDf-258	?>7 	@?88 	Af  l-vFAKOcByQc3koUD$JPeSDf-263	Bf  l-vFAKOcByQc3koUD$JPeSDf-264	Cf  l-vFAKOcByQc3koUD$JPeSDf-265	DABC 	E9=@D 	F9 	Gg  x	HG 	I? 	Jf  l-vFAKOcByQc3koUD$JPeSDf-260	KJ 	L9HIK 	M8EFL 	Ng  hygiene	ON 	P56MO 	Qg  
define-public	R5QMO 	Sg  syntax-violation	TS 	US 	Vf  -source expression failed to match any pattern	Wg  
datum->syntax	Xg  map	Yg  identifier?	Zg  
syntax->datum	[g  identity	\g  string->symbol	]g  
string-append	^g  symbol->string	_g  make-id	`g  _	a`33 	bg  macro-	cg  scheme-name	dc 	e8 	ff  l-vFAKOcByQc3koUD$JPeSDf-289	gf 	h9deg 	i;< 	j88 	kf  l-vFAKOcByQc3koUD$JPeSDf-283	lf  l-vFAKOcByQc3koUD$JPeSDf-284	mkl 	n9ijm 	of  l-vFAKOcByQc3koUD$JPeSDf-280	po 	q9Hep 	r8FhnFq 	s56rO 	t5QrO 	ug  
make-fluid	v5urO 	wg  cons	x5wrO 	yg  quote	z5yrO 	{5/rO 	|z{ 	}g  each-any	~3}	3~ ` g  compile- f  l-vFAKOcByQc3koUD$JPeSDf-303   9de  g  args g  body ;  888  f  l-vFAKOcByQc3koUD$JPeSDf-295 f  l-vFAKOcByQc3koUD$JPeSDf-296 f  l-vFAKOcByQc3koUD$JPeSDf-297   9  f  l-vFAKOcByQc3koUD$JPeSDf-292   9He  8FF  56O  g  define 5O  5uO  5wO  5yO  g  special-operator 5O    g  lambda 5O  g  @ g  sym :  g  m-vFAKOcByQc3koUD$JPeSDf-306 7  88  f  l-vFAKOcByQc3koUD$JPeSDf-311 f  l-vFAKOcByQc3koUD$JPeSDf-312 f  l-vFAKOcByQc3koUD$JPeSDf-313   9    f  l-vFAKOcByQc3koUD$JPeSDf-308   9H  8F  5O  5O   C 5   h     ]4	
5 4 >  "  G   
RR R"R#        h      - 1 3  @              g  msg
			 g  args			  g  filenamef  language/elisp/runtime.scm
	5
		6	 			
  g  nameg  macro-error CRiR
     h   {   ] $  CC  s       g  b
		  g  filenamef  language/elisp/runtime.scm
	<
		=	 		  g  nameg  
elisp-bool CR$%&'()  hP     ]4 54 545$  C45 4>  "  G   6           g  module
		K g  sym		K g  intf			K g  resolved			K g  fluid		(	K  g  filenamef  language/elisp/runtime.scm
	G
		H		
	I			H			J	
	!	J		$	K		(	K		+	L	
	I	M	#	K	M	
 		K	  g  nameg  
ensure-fluid! CR%*  h@      ]
4 5 $  64 >  "  G  45[C            g  module
		; g  sym		; g  resolved				;  g  filenamef  language/elisp/runtime.scm
	O
		P				P			R			Q			S			U		1	V	 			;	  g  nameg  reference-variable CR$%&+()* 
       h   >  ]4 54 5 $  X45$  4>  "  G  "  -4>  "  G  4 >  "  G  "   4 >  "  G  4	5\C  6      g  module
	  g  sym	  g  value		  g  intf		  g  resolved		   g  filenamef  language/elisp/runtime.scm
	X
		Y		
	Z			Y			\			[			^		*	]		+	_		E	a		[	b		d	b	 	i	b		v	d	 	e	 	 	  g  nameg  
set-variable! CR4./24PR   h   R   ]  C       J       g  dummy
		 g  name		 g  value			  			   CUV       h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
	l	 		"  g  
macro-typeg  syntax-rulesg  patternsg  nameg  value   C5RWXYZ[     h    y   ]4 5$  "   6       q       g  datum
		  g  filenamef  language/elisp/runtime.scm
	x			y	 	
	y			y	 		   C\]^      h0      - 1 3  454445?56       g  template-id
			0 g  data			0 g  symbols			.  g  filenamef  language/elisp/runtime.scm
	q
		x			w			t			u			u	!	)	u		+	t		0	v	 
			0
  g  nameg  make-id C_R4./2a_bstvx|     h0      ]
4  5    C             g  name
		* g  value		* g  tmp		
	*  g  filenamef  language/elisp/runtime.scm	 	"		 	2	
 	"	
 	 		*	   CUV        h(   n   ]	4 5$  @ 6      f       g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"   C5R4./2_ 	    h0      ]4  5    C       g  name
		0 g  args		0 g  body			0 g  tmp		
	0  g  filenamef  language/elisp/runtime.scm	 	"		 	2	
 	"	
 	 		0	   CUV       h(   n   ]	4 5$  @ 6      f       g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"   C5R4./2 h   P   ] C H       g  dummy
		 g  sym		 g  args			  			   CUV h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  language/elisp/runtime.scm
 	 		"  g  
macro-typeg  syntax-rulesg  patternsg  symg  argsg  ...   C5RC           g  m
		(  g  filenamef  language/elisp/runtime.scm		
	,	%
	0	'
	2	-		5	-
	7	/		:	/
 	5
	8
	<
*	G
b	O
i	X
		q
 	
   C6 
